package com.chinapnr.mis.lib.config.key.data;

import com.chinapnr.mis.lib.config.ChannelId;
import com.chinapnr.mis.lib.config.InterfaceType;
import com.chinapnr.mis.lib.config.MobilePayType;
import com.chinapnr.mis.lib.config.PnrResponseKey;
import com.chinapnr.mis.lib.config.key.trans.PayRequestKey;

/**
 * 消费接口{@link InterfaceType.Data#IT_QUERY_ORDER} 返回结果key值
 * 当交易成功{@link PnrResponseKey#KEY_RESPONSECODE} = 00时,参数生效
 */
public class QueryOrderResponseKey {

    /**
     * 交易日期，必填
     * 8位，yyyyMMdd
     */
    public static final String KEY_TRANS_DATE = "transDate";

    /**
     * 交易时间，必填
     * 6位，HHmmss
     */
    public static final String KEY_TRANS_TIME = "transTime";

    /**
     * 交易日期，必填
     * 值参见{@link ChannelId}
     */
    public static final String KEY_CHANNEL_ID = "channelId";

    /**
     * 支付渠道，必填
     * 值参见{@link MobilePayType}
     */
    public static final String KEY_MOBILE_PAY_TYPE = "mobilePayType";

    /**
     * 交易金额，必填
     * 单位 分，同{@link PayRequestKey#KEY_ORD_AMT}
     */
    public static final String KEY_ORD_AMT = "ordAmt";

    /**
     * 汇付交易流水号，必填
     * 后台唯一标识
     */
    public static final String KEY_ORD_ID = "ordId";

    /**
     * 终端订单号，必填
     */
    public static final String KEY_MER_ORD_ID = "merOrdId";

    /**
     * 原交易终端订单号，必填
     */
    public static final String KEY_ORI_MER_ORD_ID = "oriMerOrdId";

    /**
     * 批次号，非必填
     * 6位
     */
    public static final String KEY_BATCH_ID = "batchId";

    /**
     * 凭证号，必填
     * 6位
     */
    public static final String KEY_VOUCHER_NO = "voucherNo";

    /**
     * 参考号，必填
     * 12位
     */
    public static final String KEY_REF_NO = "refNo";

    /**
     * 银行名称，非必填
     */
    public static final String KEY_BANK_NAME = "bankName";

    /**
     * 借贷记标识，非必填
     * C-信用卡, D-借记卡
     */
    public static final String KEY_CARD_TYPE = "cardType";

    /**
     * 交易卡号，非必填
     * 前4后6显示，中间字符*隐藏
     */
    public static final String KEY_PAY_CARD_ID = "payCardId";

    /**
     * 授权号，非必填
     */
    public static final String KEY_AUTH_NO = "authNo";

    /**
     * 商户号，必填
     */
    public static final String KEY_MEMBER_ID = "memberId";

    /**
     * 商户名称，非必填
     */
    public static final String KEY_MER_NAME = "merName";

    /**
     * 交易状态
     * <ul>
     *     <li>I 初始</li>
     *     <li>S 成功</li>
     *     <li>F 失败</li>
     *     <li>P 处理中</li>
     *     <li>C 撤销</li>
     *     <li>X 冲正</li>
     *     <li>H 部分退货</li>
     *     <li>R 全部退货</li>
     * </ul>
     */
    public static final String KEY_TRANS_STAT = "transStat";

    /**
     * 已退金额
     */
    public static final String KEY_REF_AMT = "refAmt";

    /**
     * 扫码交易单号，非必填
     * 支付宝、微信交易号
     */
    public static final String KEY_TRADE_NO = "tradeNo";


    /**
     * 商户单号，非必填
     * 用于退款，指支付宝、微信商户单号
     */
    public static final String KEY_PART_ORDER_ID = "partOrderId";
    /**
     * 原正向交易的外部订单号，非必填
     */
    public static final String KEY_ORI_OUT_ORDER_ID = "oriOutOrderId";
    /**
     * 原正向交易的终端订单号，非必填
     */
    public static final String KEY_ORI_TERM_ORD_ID = "oriTermOrdId";

}
