package com.chinapnr.mis.lib.config.key.manager;


import com.chinapnr.mis.lib.config.ChannelId;
import com.chinapnr.mis.lib.config.InterfaceType;

/**
 * 补打印签购单接口{@link InterfaceType.Manager#IT_REPRINT} 请求参数key值
 */
public class ReprintRequestKey {

    /**
     * 商户号，非必填
     * 不传时默认使用收银台的商户入账；否则采用相应的第三方商户入账
     */
    public static final String KEY_MEMBER_ID = "memberId";

    /**
     * 逻辑终端号，非必填
     * 商户登录完成后，由后台自动生成的汇付内部终端号，可以不填
     */
    public static final String KEY_PNR_DEV_ID = "pnrDevId";

    /**
     * 操作员，非必填，memberId不为空且与本地商户不一致时必填
     */
    public static final String KEY_MER_OPER_ID = "merOperId";

    /**
     * 打印操作员标识，非必填
     * 是否打印当前交易操作员，memberId为空时强制为本地操作员，memberId不为空时选填，如下说明：
     * “0”：交易上传的操作员
     * “1”或“”或null：本地操作员
     */
    public static final String KEY_MER_OPER_ID_PRINTED = "merOperIdPrinted";

    /**
     * 支付渠道，必填
     *  仅支持以下值
     *  <ul>
     *      <li>银行卡 {@link ChannelId#CHANNEL_BANK }</li>
     *      <li>扫一扫 {@link ChannelId#CHANNEL_SCAN }</li>
     * </ul>
     *
     */
    public static final String KEY_CHANNEL_ID = "channelId";

    /**
     * 需打印的订单对应的订单号，
     * 原交易返回的termOrdId
     * {@link #KEY_TERM_ORD_ID}、{@link #KEY_OUT_ORD_ID}、{@link #KEY_PARTY_ORDER_ID}、{@link #KEY_TRADE_NO}必填一个
     */
    public static final String KEY_TERM_ORD_ID = "termOrdId";
    /**
     * 需打印的订单对应的三方订单，非必填
     * 对应原交易返回的outOrdId
     * {@link #KEY_TERM_ORD_ID}、{@link #KEY_OUT_ORD_ID}、{@link #KEY_PARTY_ORDER_ID}、{@link #KEY_TRADE_NO}必填一个
     */
    public static final String KEY_OUT_ORD_ID = "outOrdId";
    /**
     * 需打印的订单对应的微信或支付宝商户单号，非必填
     * 对应原交易返回的partyOrdId
     * {@link #KEY_TERM_ORD_ID}、{@link #KEY_OUT_ORD_ID}、{@link #KEY_PARTY_ORDER_ID}、{@link #KEY_TRADE_NO}必填一个
     */
    public static final String KEY_PARTY_ORDER_ID = "partyOrderId";
    /**
     * 需打印的订单对应的微信或支付宝交易单号
     * 对应原交易返回的tradeNo
     * {@link #KEY_TERM_ORD_ID}、{@link #KEY_OUT_ORD_ID}、{@link #KEY_PARTY_ORDER_ID}、{@link #KEY_TRADE_NO}必填一个
     */
    public static final String KEY_TRADE_NO = "tradeNo";
    /**
     * 是否消费交易，非必填
     * 0:否(即反向交易)
     * 1或者其他: 是（即正向交易)
     */
    public static final String KEY_IS_SALE = "isSale";



}
