package com.chinapnr.mis.lib.config.key.trans;

import com.chinapnr.mis.lib.config.ChannelId;
import com.chinapnr.mis.lib.config.InterfaceType;
import com.chinapnr.mis.lib.config.MobilePayType;
import com.chinapnr.mis.lib.config.PnrResponseKey;

/**
 * 花呗分期接口{@link InterfaceType.Trans#IT_HBFQ} 返回结果key值
 * 当交易成功{@link PnrResponseKey#KEY_RESPONSECODE} = 0时,参数生效
 */
public class HBFQResponseKey {

    /**
     * 交易日期，必填
     * 8位，yyyyMMdd
     */
    public static final String KEY_TRANS_DATE = "transDate";

    /**
     * 交易时间，必填
     * 6位，HHmmss
     */
    public static final String KEY_TRANS_TIME = "transTime";

    /**
     * 交易日期，必填
     * 值为{@link ChannelId#CHANNEL_QR_CODE} 或{@link ChannelId#CHANNEL_SCAN}
     */
    public static final String KEY_CHANNEL_ID = "channelId";

    /**
     * 支付渠道，必填
     * 值为{@link MobilePayType#PAYTYPE_ALI}
     */
    public static final String KEY_MOBILE_PAY_TYPE = "mobilePayType";

    /**
     * 交易金额，必填
     * 单位 分，同{@link HBFQRequestKey#KEY_ORD_AMT}
     */
    public static final String KEY_ORD_AMT = "ordAmt";

    /**
     * 汇付交易流水号，必填
     * 后台唯一标识
     */
    public static final String KEY_ORD_ID = "ordId";

    /**
     * 批次号，非必填
     * 6位
     */
    public static final String KEY_BATCH_ID = "batchId";

    /**
     * 凭证号，必填
     * 6位
     */
    public static final String KEY_VOUCHER_NO = "voucherNo";

    /**
     * 参考号，必填
     * 12位
     */
    public static final String KEY_REF_NO = "refNo";

    /**
     * 授权号，非必填
     */
    public static final String KEY_AUTH_NO = "authNo";

    /**
     * 商户号，必填
     */
    public static final String KEY_MEMBER_ID = "memberId";

    /**
     * 商户名称，非必填
     */
    public static final String KEY_MER_NAME = "merName";

    /**
     * 用户ID，非必填
     * 用户标志，支付宝是用户名
     */
    public static final String KEY_OPEN_ID = "openID";

    /**
     * 扫码交易单号，非必填
     * 支付宝、微信交易号
     */
    public static final String KEY_TRADE_NO = "tradeNo";

    /**
     * 物理终端号，非必填
     * 汇付终端号
     */
    public static final String KEY_DEVICE_ID = "deviceId";

    /**
     * 订单号，非必填
     * outOrdId对应传入的merOrdId{@link HBFQRequestKey#KEY_OUT_ORD_ID}，merOrdId为空本字段为空
     */
    public static final String KEY_OUT_ORD_ID = "outOrdId";

    /**
     * 终端订单号，必填
     * 终端收银台生成的订单号
     */
    public static final String KEY_TERM_ORD_ID = "termOrdId";

    /**
     * 商户单号，非必填
     * 用于退款，指支付宝、微信商户单号
     */
    public static final String KEY_PART_ORDER_ID = "partOrderId";

}
