package com.chinapnr.mis.lib.config.key.trans;

import com.chinapnr.mis.lib.config.ChannelId;
import com.chinapnr.mis.lib.config.InterfaceType;

/**
 * 消费退款接口{@link InterfaceType.Trans#IT_REFUND} 请求参数key值
 */
public class RefundRequestKey {


    /**
     * 商户号，非必填
     * 不传时默认使用收银台的商户入账；否则采用相应的第三方商户入账
     */
    public static final String KEY_MEMBER_ID = "memberId";

    /**
     * 操作员，非必填，memberId不为空且与本地商户不一致时必填
     */
    public static final String KEY_MER_OPER_ID = "merOperId";

    /**
     * 打印操作员标识，非必填
     * 是否打印当前交易操作员，memberId为空时强制为本地操作员，memberId不为空时选填，如下说明：
     * “0”：交易上传的操作员
     * “1”或“”或null：本地操作员
     */
    public static final String KEY_MER_OPER_ID_PRINTED = "merOperIdPrinted";

    /**
     * 订单金额，必填
     * 12位以内数字，单位 为 分
     */
    public static final String KEY_ORD_AMT = "ordAmt";

    /**
     * 原订单号，{@link #KEY_OORI_TERM_ORD_ID }和{@link #KEY_ORI_OUT_ORDER_ID}必传一个
     * 对应原消费交易{@link PayResponseKey#KEY_TERM_ORD_ID}
     */
    public static final String KEY_OORI_TERM_ORD_ID = "oriTermOrdId";

    /**
     * 原三方订单号，{@link #KEY_OORI_TERM_ORD_ID }和{@link #KEY_ORI_OUT_ORDER_ID}必传一个
     * 对应原消费交易{@link PayResponseKey#KEY_OUT_ORD_ID}
     */
    public static final String KEY_ORI_OUT_ORDER_ID = "oriOutOrderId";

    /**
     * 商户自定义订单号，非必填
     * 扫码交易， 变长1-50位
     * 银行卡交易， 变长20-40位
     * 订单号规则建议: 14位时间 +6 位随机数,如：201711180000001000001
     */
    public static final String KEY_OUT_ORD_ID = "outOrdId";

    /**
     * 异步通知地址，非必填
     * 200位以内； URL中如带端口需在8000~10000范围内或者80、443；
     */
    public static final String KEY_BG_RET_URL = "bgRetUrl";

    /**
     * 商户私有域，非必填
     * 可填写商户自有信息，会在交易结果和异步回调中返回
     */
    public static final String KEY_MER_PRIV = "merPriv";

    /**
     * 订单备注，非必填
     * 备注中要包含的内容（UTF-8格式，长度为45个字符）
     */
    public static final String KEY_ORD_REMARK = "ordRemark";

    /**
     * 支付渠道，必填
     *  仅支持以下值
     *  <ul>
     *      <li>银行卡 {@link ChannelId#CHANNEL_BANK }</li>
     *      <li>扫一扫 {@link ChannelId#CHANNEL_SCAN }</li>
     * </ul>
     *
     */
    public static final String KEY_CHANNEL_ID = "channelId";


    /**
     * 自定义第三方打印数据，非必填
     *  json串
     *  示例：{"merName":"huifu","address":"上海徐汇区",……}
     */
    public static final String KEY_OUT_PRINT_DATA = "outPrintData";

    /**
     * 自定义第三方打印二维码，非必填
     * json串，此json串转成二维码并打印
     */
    public static final String KEY_OUT_PRINT_QR_CODE = "outPrintQrCode";



}
