package com.chinapnr.mis.lib.config.key.trans;

import com.chinapnr.mis.lib.config.ChannelId;
import com.chinapnr.mis.lib.config.InterfaceType;
import com.chinapnr.mis.lib.config.MobilePayType;
import com.chinapnr.mis.lib.config.PnrResponseKey;

/**
 * 消费撤销接口{@link InterfaceType.Trans#IT_VOID} 返回结果key值
 * 当交易成功{@link PnrResponseKey#KEY_RESPONSECODE} = 0时,参数生效
 */
public class VoidResponseKey {

    /**
     * 交易日期，必填
     * 8位，yyyyMMdd
     */
    public static final String KEY_TRANS_DATE = "transDate";

    /**
     * 交易时间，必填
     * 6位，HHmmss
     */
    public static final String KEY_TRANS_TIME = "transTime";

    /**
     * 交易日期，必填
     * 值参见{@link ChannelId}
     */
    public static final String KEY_CHANNEL_ID = "channelId";

    /**
     * 支付渠道，必填
     * 值参见{@link MobilePayType}
     */
    public static final String KEY_MOBILE_PAY_TYPE = "mobilePayType";

    /**
     * 交易金额，必填
     * 单位 分，同{@link PayRequestKey#KEY_ORD_AMT}
     */
    public static final String KEY_ORD_AMT = "ordAmt";

    /**
     * 汇付交易流水号，必填
     * 后台唯一标识
     */
    public static final String KEY_ORD_ID = "ordId";

    /**
     * 原交易终端订单号，必填
     */
    public static final String KEY_ORI_TERM_ORD_ID = "oriTermOrdId";

    /**
     * 批次号，非必填
     * 6位
     */
    public static final String KEY_BATCH_ID = "batchId";

    /**
     * 凭证号，必填
     * 6位
     */
    public static final String KEY_VOUCHER_NO = "voucherNo";

    /**
     * 参考号，必填
     * 12位
     */
    public static final String KEY_REF_NO = "refNo";

    /**
     * 银行名称，非必填
     */
    public static final String KEY_BANK_NAME = "bankName";

    /**
     * 借贷记标识，非必填
     * C-信用卡, D-借记卡
     */
    public static final String KEY_CARD_TYPE = "cardType";

    /**
     * 交易卡号，非必填
     * 前4后6显示，中间字符*隐藏
     */
    public static final String KEY_PAY_CARD_ID = "payCardId";

    /**
     * 授权号，非必填
     */
    public static final String KEY_AUTH_NO = "authNo";

    /**
     * 商户号，必填
     */
    public static final String KEY_MEMBER_ID = "memberId";

    /**
     * 商户名称，非必填
     */
    public static final String KEY_MER_NAME = "merName";


    /**
     * 银联商户号，非必填
     * 银行卡交易才返回此字段
     */
    public static final String KEY_POS_MER_ID = "posMerId";

    /**
     * 用户ID，非必填
     * 用户标志，支付宝是用户名
     */
    public static final String KEY_OPEN_ID = "openID";

    /**
     * 扫码交易单号，非必填
     * 支付宝、微信交易号
     */
    public static final String KEY_TRADE_NO = "tradeNo";

    /**
     * 物理终端号，非必填
     * 汇付终端号
     */
    public static final String KEY_DEVICE_ID = "deviceId";

    /**
     * 订单号，非必填
     * outOrdId对应传入的merOrdId{@link VoidRequestKey#KEY_OUT_ORD_ID}，merOrdId为空本字段为空
     */
    public static final String KEY_OUT_ORD_ID = "outOrdId";

    /**
     * 终端订单号，必填
     * 终端收银台生成的订单号
     */
    public static final String KEY_TERM_ORD_ID = "termOrdId";

    /**
     * 原三方交易订单号，非必填
     * 用于退款，指支付宝、微信商户单号
     */
    public static final String KEY_ORI_OUT_ORDER_ID = "oriOutOrderId";

}
