package com.chinapnr.mis.lib.ui;

import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import android.widget.Button;
import android.widget.ListView;
import android.widget.ProgressBar;
import android.widget.TextView;

import androidx.annotation.NonNull;

import com.blankj.utilcode.util.ScreenUtils;
import com.chinapnr.mis.lib.R;
import com.chinapnr.mis.lib.bean.Device;

import java.util.ArrayList;
import java.util.List;


public class CommonListDialog extends Dialog {
    private ListView lv_common;
    private CommonListAdapter adapter;
    private TextView tv_title, tv_cancel;
    private DialogCallback dialogCallback;
    private ProgressBar pb_progress;

    private String titleText;
    private List<Device> dataList;

    public CommonListDialog(@NonNull Context context) {
        super(context, R.style.MyDialog);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);

        setContentView(R.layout.dialog_common_list);
        setCancelable(false);
        setCanceledOnTouchOutside(false);
        initView();
        initData();
        initEvent();
    }

    private void initView(){
        tv_cancel = findViewById(R.id.tv_cancel);
        tv_title = findViewById(R.id.tv_title);
        pb_progress = findViewById(R.id.pb_progress);
        lv_common = findViewById(R.id.lv_common);
        int height = ScreenUtils.getScreenHeight();
        ViewGroup.LayoutParams lp = lv_common.getLayoutParams();
        lp.height = height / 2 ;
        adapter = new CommonListAdapter(getContext(), null);
        lv_common.setAdapter(adapter);

    }
    private void initData(){
        if (tv_title != null){
            tv_title.setText(titleText);
        }
        if (adapter != null && dataList != null){
            adapter.setDataList(dataList);
            adapter.notifyDataSetChanged();
        }
    }

    private void initEvent(){
        if (tv_cancel != null){
            tv_cancel.setOnClickListener(v -> {
                dismiss();
                if (dialogCallback != null){
                    dialogCallback.cancel();
                }
            });
        }
        if (lv_common != null){
            lv_common.setOnItemClickListener((parent, view, position, id) -> {
                Device device = (Device) adapter.getItem(position);
                dialogCallback.commit(device);
                dismiss();
            });
        }
    }

    public CommonListDialog setTitleText(String text) {
        this.titleText = text;
        initData();
        return this;
    }



    public CommonListDialog setBackEnable(boolean flag) {
        this.setCancelable(flag);
        return this;
    }
    public CommonListDialog setOutEnable(boolean flag) {
        this.setCanceledOnTouchOutside(flag);
        return this;
    }

    public CommonListDialog setListData(List<Device> dataList) {
        this.dataList = dataList;
        initData();
        return this;
    }
    public CommonListDialog addData(Device device){
        if (this.dataList == null){
            this.dataList = new ArrayList<>();
        }
        this.dataList.add(device);
        initData();
        return this;
    }

    public void showProgress(){
        if (pb_progress != null){
            pb_progress.setVisibility(View.VISIBLE);
        }
    }

    public void hideProgress(){
        if (pb_progress != null){
            pb_progress.setVisibility(View.INVISIBLE);
        }
    }

    public CommonListDialog updateData(){
        initData();
        return this;
    }

    public CommonListDialog setCallBackListener(DialogCallback dialogCallback){
        this.dialogCallback = dialogCallback;
        initEvent();
        return this;
    }

    @Override
    public void show() {
        super.show();

    }

    public interface DialogCallback {
        void commit(Device device);
        void cancel();
    }
}

