package com.chinapnr.mis.lib.ui;

import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.TextView;

import androidx.annotation.NonNull;

import com.chinapnr.mis.lib.R;


public class WaitingProgressView {

    private WaitingProgressDialog dialog;

    public static WaitingProgressView sInstance;

    public static WaitingProgressView getInstance(Context context){
        if (sInstance != null) {
            return sInstance;
        }
        synchronized (WaitingProgressView.class) {
            if (sInstance == null) {
                sInstance = new WaitingProgressView(context);
            }
        }
        return sInstance;
    }

    private WaitingProgressView(Context context) {
        dialog = new WaitingProgressDialog(context);
        dialog.setCancelable(false);
        dialog.setCanceledOnTouchOutside(false);
    }

    public void destroyWaitingView(){
        dialog = null;
    }

    public void show(CharSequence titleText, CharSequence messageText){
        if (dialog != null){
            if (!dialog.isShowing()){
                dialog.show();
            }
            dialog.setTitleText(titleText);
            dialog.setMessageText(messageText);
        }

    }

    public void dismiss(){
        if (dialog != null && dialog.isShowing()){
            dialog.dismiss();
            dialog.setEnableBack(false);
            dialog.setBackPressed(false);
        }
    }

    public boolean backPressed(){
        return  dialog.isBackPressed();
    }

    public void setBackPressed(boolean backPressed){
        dialog.setBackPressed(backPressed);
    }

    public void enableBack(){
        dialog.setEnableBack(true);
    }

    public void disableBack(){
        dialog.setEnableBack(false);
    }



    private class WaitingProgressDialog extends Dialog {

        private TextView tv_title;
        private TextView tv_message;

        private boolean backPressed;
        private boolean enableBack;

        public WaitingProgressDialog(@NonNull Context context) {
            super(context, R.style.MyDialog);
        }

        @Override
        protected void onCreate(Bundle savedInstanceState) {
            super.onCreate(savedInstanceState);
            requestWindowFeature(Window.FEATURE_NO_TITLE);
            setContentView(R.layout.dialog_waiting);
            tv_title = findViewById(R.id.tv_title);
            tv_message = findViewById(R.id.tv_message);

        }

        public void setTitleText(CharSequence text) {
            if (tv_title != null){
                tv_title.setText(text);
            }

        }

        public void setMessageText(CharSequence text) {
            if (tv_message != null){
                if (text == null){
                    tv_message.setVisibility(View.GONE);
                }else {
                    tv_message.setVisibility(View.VISIBLE);
//                    String text1 = getContext().getString(R.string.http_connecting);
//                    String text2 = "  " + text;
//                    text = text1 + text2;
//                    int start1 = text.indexOf(text1);
//                    int end1 = start1 + text1.length();
//                    int start2 = text.indexOf(text2);
//                    int end2 = start2 + text2.length();
//
//                    SpannableStringBuilder builder = new SpannableStringBuilder(text);
//                    builder.setSpan(new ForegroundColorSpan(Color.GRAY),
//                            start1, end1, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
//                    builder.setSpan(new ForegroundColorSpan(Color.RED),
//                            start2, end2, Spannable.SPAN_INCLUSIVE_INCLUSIVE);
//                    tv_message.setText(builder);
                        tv_message.setText(text);

                }

            }

        }

        @Override
        public void onBackPressed() {
            super.onBackPressed();
            if (enableBack){
                backPressed = true;
            }
        }

        public boolean isBackPressed() {
            return backPressed;
        }

        public void setBackPressed(boolean backPressed) {
            this.backPressed = backPressed;
        }

        public boolean isEnableBack() {
            return enableBack;
        }

        public void setEnableBack(boolean enableBack) {
            this.enableBack = enableBack;
        }
    }
}


