package com.chinapnr.mis.demo.ui;

import androidx.appcompat.app.AppCompatActivity;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.Toast;

import com.chinapnr.mis.demo.R;
import com.chinapnr.mis.lib.bean.Device;
import com.chinapnr.mis.lib.listener.OnSelectDeviceListener;
import com.chinapnr.mis.lib.listener.OnSendListener;
import com.chinapnr.mis.lib.socket.SocketManager;
import com.chinapnr.mis.lib.config.InterfaceType;
import com.chinapnr.mis.lib.config.PnrRequestKey;
import com.chinapnr.mis.lib.config.key.trans.PayRequestKey;
import com.google.gson.JsonObject;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Random;

public class SocketActivity extends AppCompatActivity {

    private static final String TAG = SocketActivity.class.getSimpleName();
    private EditText et_pay_data, et_device_data, et_pay_amt, et_pay_orderId;
    private Spinner sp_pay_channel;
    private String deviceName;
    private String deviceAddress;

    private String[] PAY_CHANNEL_NAME = {"银行卡", "扫码"};
    private String[] PAY_CHANNEL_CODE = {"acquire", "scan"};

    private String payChannel;
    private String amount;
    private String orderId;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_socket);
        et_pay_data = findViewById(R.id.et_pay_data);
        sp_pay_channel = findViewById(R.id.sp_pay_channel);
        et_device_data = findViewById(R.id.et_device_data);
        et_pay_amt = findViewById(R.id.et_pay_amt);
        et_pay_orderId = findViewById(R.id.et_pay_orderId);
        et_pay_amt.setText("1");


        ArrayAdapter<String> adapter = new ArrayAdapter<>(SocketActivity.this, R.layout.array_item, PAY_CHANNEL_NAME);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        sp_pay_channel.setAdapter(adapter);
        sp_pay_channel.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {

            @Override
            public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
//                if (position == 0){
//                    payChannel =
//                }
                payChannel = PAY_CHANNEL_CODE[position];
            }

            @Override
            public void onNothingSelected(AdapterView<?> parent) {
                payChannel = PAY_CHANNEL_CODE[0];
            }
        });

        findViewById(R.id.btn_device).setOnClickListener(v->{
            SocketManager.getInstance(SocketActivity.this).selectDevice(new OnSelectDeviceListener() {
                @Override
                public void onSuccess(Device device) {
                    Log.d(TAG, "选择设备[" + device.toString() + "]");
                    et_device_data.setText(device.getName() + "(" + device.getAddress() + ")");
                    deviceName = device.getName();
                    deviceAddress = device.getAddress();
                }

                @Override
                public void onError(int code, String message) {
                    Log.d(TAG, "选择设备失败[" + code + "," + message + "]");
                    Toast.makeText(SocketActivity.this, message, Toast.LENGTH_SHORT).show();
                    
                }
            });
        });

        findViewById(R.id.btn_pay).setOnClickListener(v->{
            JsonObject jsonObject = new JsonObject();
            jsonObject.addProperty(PayRequestKey.KEY_CHANNEL_ID, payChannel);
            jsonObject.addProperty(PayRequestKey.KEY_ORD_AMT, et_pay_amt.getText().toString());
            jsonObject.addProperty(PayRequestKey.KEY_OUT_ORD_ID, et_pay_orderId.getText().toString());
            jsonObject.addProperty(PayRequestKey.KEY_ORD_REMARK, "5201314");
//            tvRequest.setText("接口:" + InterfaceType.Trans.IT_PAY + "\n" + "参数：" + jsonObject.toString());

            jsonObject.addProperty(PnrRequestKey.KEY_INTERFACE_TYPE, InterfaceType.Trans.IT_PAY);

            SocketManager.getInstance(SocketActivity.this).sendMessage(new Device(deviceName, deviceAddress), jsonObject.toString(), true, new OnSendListener() {
                @Override
                public void onSendSuccess() {
                    Log.d(TAG, "发送成功");
                    Toast.makeText(SocketActivity.this, "发送成功", Toast.LENGTH_SHORT).show();
                }

                @Override
                public void onReceiveSuccess(String data) {
                    Log.d(TAG, "接收成功：" + data);
                    Toast.makeText(SocketActivity.this, "接收成功", Toast.LENGTH_SHORT).show();
                }

                @Override
                public void onError(int code, String message) {
                    Log.d(TAG, "错误：" + code + "," + message);
                    Toast.makeText(SocketActivity.this, "错误:" + message, Toast.LENGTH_SHORT).show();
                }
            });
        });
    }

    @Override
    protected void onResume() {
        super.onResume();
        et_pay_orderId.setText(getRandomMemberOrderId());
    }

    public String getRandomMemberOrderId(){
        Random random = new Random();
        return new SimpleDateFormat("yyyyMMddHHmmss").format(new Date()) + "E" + String.format("%05d", random.nextInt(100000));
    }
}