package com.chinapnr.mis.demo.utils;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.preference.PreferenceManager;


/**
 * SharedPreferences工具类
 * 
 * @author Zhoujun 说明：SharedPreferences的操作工具类，需要缓存到SharedPreferences中的数据在此设置。
 */
public class SharedPrefUtil {

	private Context context;
	private static SharedPrefUtil instance;
	private final String SPNAME = "config";


	private SharedPrefUtil(Context context) {
		this.context = context;
	}

	public static SharedPrefUtil getInstance(Context context) {
		if (instance == null) {
			instance = new SharedPrefUtil(context);
		}
		return instance;
	}


	
	public void putString(String key, String value) {
		SharedPreferences preferences = context.getSharedPreferences(SPNAME, Context.MODE_PRIVATE);
		Editor editor = preferences.edit();
		editor.putString(key, value);
		editor.commit();
	}

	public String getString(String key, String defValue) {
		SharedPreferences preferences = context.getSharedPreferences(SPNAME, Context.MODE_PRIVATE);
		return preferences.getString(key, defValue);
	}

	public void putInt(String key, Integer value) {
		SharedPreferences preferences = context.getSharedPreferences(SPNAME, Context.MODE_PRIVATE);
		Editor editor = preferences.edit();
		editor.putInt(key, value);
		editor.commit();
	}

	public Integer getInt(String key, Integer defValue) {
		SharedPreferences preferences = context.getSharedPreferences(SPNAME, Context.MODE_PRIVATE);
		return preferences.getInt(key, defValue);
	}


	public void setBoolean(String key, boolean value){
		SharedPreferences preferences = context.getSharedPreferences(SPNAME, Context.MODE_PRIVATE);
		Editor editor = preferences.edit();
		editor.putBoolean(key, value);
		editor.commit();
	}
	
	public boolean isBoolean(String key, boolean defValue){
		SharedPreferences preferences = context.getSharedPreferences(SPNAME, Context.MODE_PRIVATE);
		return preferences.getBoolean(key, defValue);
	}



	/**
	 * 
	 * removeDefaultSharedPreferences: 移除系统默认存在SharedPreferences数据. <br/>
	 * 
	 * @author mwd
	 * @param context
	 * @param key
	 * @since JDK 1.8
	 */
	public static void removeDefaultSharedPreferences(Context context, String key) {
		SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
		Editor e = sp.edit();
		e.remove(key);
		e.commit();
	}

	/**
	 * 
	 * setStringDefaultSharedPreferences: 保存数据到默认存在SharedPreferences,数据类型String. <br/>
	 * 
	 * @author mwd
	 * @param context
	 * @param key
	 * @since JDK 1.8
	 */
	public static void setStringDefaultSharedPreferences(Context context, String key, String values) {
		SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
		Editor e = sp.edit();
		e.putString(key, values);
		e.commit();
	}

	/**
	 * 
	 * getStringDefaultSharedPreferences: 获取数据到默认存在SharedPreferences,数据类型String. <br/>
	 * 
	 * @author mwd
	 * @param context
	 * @param key
	 * @since JDK 1.8
	 */
	public static String getStringDefaultSharedPreferences(Context context, String key, String values) {
		SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
		return sp.getString(key, values);
	}

	/**
	 * 
	 * setIntDefaultSharedPreferences: 保存数据到默认存在SharedPreferences,数据类型int. <br/>
	 * 
	 * @author mwd
	 * @param context
	 * @param key
	 * @since JDK 1.8
	 */
	public static void setIntDefaultSharedPreferences(Context context, String key, Integer values) {
		SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
		Editor e = sp.edit();
		e.putInt(key, values);
		e.commit();
	}

	/**
	 * 
	 * getIntDefaultSharedPreferences: 获取数据到默认存在SharedPreferences,数据类型int. <br/>
	 * 
	 * @author mwd
	 * @param context
	 * @param key
	 * @since JDK 1.8
	 */
	public static Integer getIntDefaultSharedPreferences(Context context, String key, Integer values) {
		SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
		return sp.getInt(key, values);
	}
}
